.. |I2C| replace:: I\ :sup:`2`\ C

.. _FT232R: http://www.ftdichip.com/Products/ICs/FT232R.htm
.. _FT230X: http://www.ftdichip.com/Products/ICs/FT230X.html
.. _FT2232D: http://www.ftdichip.com/Products/ICs/FT2232D.htm
.. _FT232H: http://www.ftdichip.com/Products/ICs/FT232H.htm
.. _FT2232H: http://www.ftdichip.com/Products/ICs/FT2232H.html
.. _FT4232H: http://www.ftdichip.com/Products/ICs/FT4232H.htm
.. _tests/gpio.py: https://github.com/eblot/pyftdi/blob/master/pyftdi/tests/gpio.py
.. _tests/spi.py: https://github.com/eblot/pyftdi/blob/master/pyftdi/tests/spi.py
.. _tests/i2c.py: https://github.com/eblot/pyftdi/blob/master/pyftdi/tests/i2c.py
.. _PyFtdi: https://www.github.com/eblot/pyftdi
.. _FTDI: http://www.ftdichip.com/
.. _PyUSB: http://pyusb.github.io/pyusb/
.. _Python: https://www.python.org/
.. _pyserial: https://pythonhosted.org/pyserial/
.. _libftdi: https://www.intra2net.com/en/developer/libftdi/
.. _pyspiflash: https://github.com/eblot/pyspiflash/
.. _pyi2cflash: https://github.com/eblot/pyi2cflash/
.. _libusb: http://www.libusb.info/
.. _Libusb on Windows: https://github.com/libusb/libusb/wiki/Windows
.. _Libusb win32: https://sourceforge.net/projects/libusb-win32/files/libusb-win32-releases/
.. _Zadig: http://zadig.akeo.ie/
.. _FTDI macOS guide: http://www.ftdichip.com/Support/Documents/AppNotes/AN_134_FTDI_Drivers_Installation_Guide_for_MAC_OSX.pdf
.. _Libusb issue on macOs: https://github.com/libusb/libusb/commit/5e45e0741daee4fa295c6cc977edfb986c872152

